function [interval_rat_quants]=Interval_nonrejected_quantiles(y1, y2, clevel)
% interval_rat_quants gives the interval of the subjective quantiles that
% are consistent with rationality of the agents, i.e.: [Pr( y2<=k-1 | y1 = k), 
% Pr( y2<=k | y1 = k)] given by Madeira(2015)

% y1 is a [N x 1] column vector of expectations
% y2 is a [N x 1] column vector of results 
% clevel is the confidence level of the test statistic for not-rejecting
% rationality (ex: 1%, 5%, 10%)

vmin=min([y1; y2]); vmax=max([y1; y2]); v=vmin:vmax; obs_v=histc([y1; y2], v);
for i = 1:size(obs_v, 1);
    if obs_v(i, 1)==0;
        v(1, i) =NaN;  % if value has no obs, mark it as missing
    end
end
v = v(logical( isnan(v)==0 ) )';  % values that never appear will not be used for computing probabilities
nr_v = size(v, 1);  

interval_rat_quants = NaN.*zeros(nr_v,2);
for j=1:999; alpha_j=j/1000;
[p_joint_j] = Multiplecondition_quantile_test(y1, y2, alpha_j); %[p_joint_j, a1,a2,a3,a4, prob_exp_quant]=Multiplecondition_quantile_test(y1, y2, alpha_j);
ind_j = logical(p_joint_j>=clevel);
interval_rat_quants(ind_j,1)=nanmin(alpha_j,interval_rat_quants(ind_j,1));
interval_rat_quants(ind_j,2)=nanmax(alpha_j,interval_rat_quants(ind_j,1));
end
