function [interval_rat_quants]=Interval_nonrejected_quantiles_condX(y1, y2, x, clevel)
% interval_rat_quants gives the interval of the subjective quantiles that
% are consistent with rationality of the agents, i.e.: [Pr( y2<=k-1 | y1 = k), 
% Pr( y2<=k | y1 = k)] given by Madeira(2015)

% y1 is a [N x 1] column vector of expectations
% y2 is a [N x 1] column vector of results
% x is a [N x 1] column vector of discrete covariates (ex: parental
% education or past grades)
% clevel is the confidence level of the test statistic for not-rejecting
% rationality (ex: 1%, 5%, 10%)

vmin=min([y1; y2]); vmax=max([y1; y2]); v=vmin:vmax;  obs_v=histc([y1; y2], v);
for i = 1:size(obs_v, 1);
    if obs_v(i, 1)==0;
        v(1, i) =NaN;  % if value has no obs, mark it as missing
    end
end
v = v(logical( isnan(v)==0 ) )';  % values that never appear will not be used for computing probabilities
nr_v=size(v, 1);  xmin=min(x);  xmax=max(x); xv=xmin:xmax;  obs_x=histc(x, xv);
for i = 1:size(obs_x, 1);
    if obs_x(i, 1)==0;
        xv(1, i) =NaN;  % if value has no obs, mark it as missing
    end
end
xv = xv(logical( isnan(xv)==0 ) )';  % values that never appear will not be used for computing probabilities
nr_x = size(xv, 1);

interval_rat_quants = NaN.*zeros(nr_v, nr_x,2);
for i=1:nr_x; ind=logical(x==xv(i,1));
    [ix]=Interval_nonrejected_quantiles(y1(ind), y2(ind), clevel);
    interval_rat_quants(:,i,1)=ix(:,1); interval_rat_quants(:,i,2)=ix(:,2);
end
