function [p]=Multiplecondition_mode_test_condX(y1, y2, x)
% Function gives the p-value of the test described by Das-Dominitz and Soest (1999) for the expectations of  discrete outcomes
% This function makes the test that agents are both rational and express expectations as their subjective Mode
% This function differs from version 1 in the sense that it conditions results on the values of x

% y1 is a [N x 1] column vector of expectations
% y2 is a [N x 1] column vector of results 
% y1 and y2 are assumed to be discrete (i.e, values = 0, 1, 2, 3,..., n belong to integer numbers)  
% x is the covariate that is used to condition the test of expectations (suggestions for x: race, sex or the value of the previous mark)
% I assume that x is a single covariate [N x 1]

% asymptotic variance for Pr( y2=k | x=jl, y1 = k)-Pr( y2=j | x=jl, y1 = k) 
% is 2p1=2*Pr( y2=k | y2_lag=jl, y1 = k) 

% Results:
% p is the p-value for the test: Pr( y2=k | x=jl, y1 = k)-max(j: Pr( y2=j | x=jl, y1 = k) )
% jl is the same for each column and k is the same for each row


vmin=min([y1; y2]);  vmax=max([y1; y2]);  v=vmin:vmax;
obs_v = histc([y1; y2], v);
for i = 1:size(obs_v, 1);
    if obs_v(i, 1)==0;
        v(1, i) =NaN;  % if value has no obs, mark it as missing
    end
end
v = v(logical( isnan(v)==0 ) )';  % values that never appear will not be used for computing probabilities
nr_v = size(v, 1);

xmin=min(x);  xmax=max(x);  xv=xmin:xmax;
obs_x = histc(x, xv);
for i = 1:size(obs_x, 1);
    if obs_x(i, 1)==0;
        xv(1, i) =NaN;  % if value has no obs, mark it as missing
    end
end
xv = xv(logical( isnan(xv)==0 ) )';  % values that never appear will not be used for computing probabilities
nr_x = size(xv, 1);

p = NaN.*zeros(nr_v, nr_x);
for i =1:nr_x;
    ind = logical(x==xv(i,1));
    try
    warning('off','all');
    p(:, i) = Multiplecondition_mode_test(y1(ind), y2(ind)); %das_dominitz_soest_mode_test(y1(ind), y2(ind), option_var);
    catch err
    p(:,i) = NaN(size(p(:, i)));        
    end
end
