function [prob_v_condy1]=Prob_outcomes_condY1(y1, y2)
% y1 is a [N x 1] column vector of expectations
% y2 is a [N x 1] column vector of results 
% y1 and y2 are assumed to be discrete (i.e, values = 0, 1, 2, 3,..., n belong to integer numbers)  

% Results:
% prob_v_condy1 is the pdf  Pr( y2== j | y1 = k) where j is row and k is column

vmin=min([y1; y2]);  vmax=max([y1; y2]);  v=vmin:vmax; obs_v=histc([y1; y2], v);
for i = 1:size(obs_v, 1);
    if obs_v(i, 1)==0;
        v(1, i) =NaN;  % if value has no obs, mark it as missing
    end
end
v = v(logical( isnan(v)==0 ) )';  % values that never appear will not be used for computing probabilities

nr_v=size(v, 1); prob_v_condy1=NaN.*zeros(nr_v);       
for j=1:nr_v; ind=find( y1 == v(j,1) & isnan(y2)==0 );   Ny=size(ind, 1); 
    if Ny>=2; % if size is positive, estimate conditional sample-probabilities (otherwise, they are missing)
    prob_v_condy1(:, j) = histc( y2(ind,1) , v')/Ny;              
    end
end
