function [p]=pvalue_weighted_chi(x0, wald_test,covar_other_guesses)
% Function gives the p-value of the weighted chi-square test as explained
% in Shapiro (1985), Wolak (1987) or Kudo (1963) for multivariate one-sided confidence test  

R=corrcov(covar_other_guesses);
    
if size(x0,2)==1;   
p = (1/2)*logical(0>=wald_test) +(1/2)*(chi2cdf(wald_test, 1,'upper'));

elseif size(x0,2)==2; 
corr12=R(1,2); %corr12 = covar_other_guesses(1,2)./sqrt(covar_other_guesses(1,1).*covar_other_guesses(2,2));
w0 = (1/2)*inv(pi)*acos(corr12); w1 = 1/2; w2=1/2-w0;   %w0 = (1/2)*inv(pi)*(pi-acos(corr12)); w1 = 1/2; w2=1/2-w0; %corr(1,2)  
p = w2*logical(0>=wald_test) +w1*(chi2cdf(wald_test, 1,'upper')) +  w0*(chi2cdf(wald_test, 2,'upper')); %p(j, 1) = w0*logical(0>=wald_test) +w1*(1-chi2cdf(wald_test, 1)) +  w2*(1-chi2cdf(wald_test, 2));                     

elseif size(x0,2)==3;  
corr12=R(1,2); corr13=R(1,3); corr23=R(2,3);
corr12_3=(R(1,2)-R(1,3)*R(2,3))./sqrt((1-R(1,3).^2).*((1-R(2,3).^2)));
corr13_2=(R(1,3)-R(1,2)*R(3,2))./sqrt((1-R(1,2).^2).*((1-R(3,2).^2)));
corr23_1=(R(2,3)-R(2,1)*R(3,1))./sqrt((1-R(2,1).^2).*((1-R(3,1).^2)));

w2=(1/4)*inv(pi)*(3*pi-acos(corr12_3)-acos(corr13_2)-acos(corr23_1));
w3=(1/4)*inv(pi)*(2*pi-acos(corr12)-acos(corr13)-acos(corr23));
w0=(1/2)-w2; w1=(1/2)-w3;
p = w3*logical(0>=wald_test) + w2*(chi2cdf(wald_test, 1,'upper')) + w1*(chi2cdf(wald_test, 2,'upper')) + w0*(chi2cdf(wald_test, 3,'upper')); %p = w3*logical(0>=wald_test) + w2*(1-chi2cdf(wald_test, 1)) + w1*(1-chi2cdf(wald_test, 2)) + w0*(1-chi2cdf(wald_test, 3));  %p(j, 1) = w0*logical(0>=wald_test) + w1*(1-chi2cdf(wald_test, 1)) + w2*(1-chi2cdf(wald_test, 2)) + w3*(1-chi2cdf(wald_test, 3));                     

else  % Formula for size 4 of Shapiro (1985) depends on a term difficult to 
  % evaluate, so for nr_v>=5, use an upper bound given by Perlman (1969)
p = (1/2)*(chi2cdf(wald_test, size(x0,2)-1,'upper')) + (1/2)*(chi2cdf(wald_test, size(x0,2),'upper'));  %p = (1/2)*(1-chi2cdf(wald_test, size(x0,2)-1)) + (1/2)*(1-chi2cdf(wald_test, size(x0,2)));                           
end
