% This file performs the tests suggested by Madeira (2016) for expectations of categorical variables
% on the BSS dataset
% We test therefore 1) the joint hypothesis that agents are rational and express their subjective Mode
% 2) the joint hypothesis that agents are rational and express their subjective Median

clear all; close all; tic; load data_bss5; %% math_pmemMean read_pmemMean % noup_allw_pmax (excludes 13.66% of obs) noup_allw_smax (excludes 27.46% of obs)

% 0 - Parents expectations tests conditional on mother's education and
% first year guesses (1982), conditional on mother's education for all
% years, whether they update guesses or not, and whether they remember past marks or not
clevel = 0.05; % confidence level of test for not-rejecting rationality
nr_y=length(year)/length(math_pmemMean); warning off all; 

% Test conditional on maternal education (mom_yrs_educ2, dad_yrs_educ2)
for j=1:3; % 1982 guesses
if j==1; ind=logical(mom_yrs_educ2<12 & year==1982); end 
if j==2; ind=logical(mom_yrs_educ2==12 & year==1982); end
if j==3; ind=logical(mom_yrs_educ2>12 & year==1982); end    
pmaxq1=pmax82q1_rec(ind); mark_mathq1=mark_math82q1(ind);

[p_pmaxq1_kudo2(:,:,j)] = Multiplecondition_mode_test(pmaxq1, mark_mathq1); %   % Parents % Mode and Median  %
[p_joint_pmaxq1_kudo(:,:,j)] = Multiplecondition_quantile_test(pmaxq1, mark_mathq1, 0.50);
end

% Test conditional on maternal education (mom_yrs_educ2, dad_yrs_educ2)
for j=4:6; % All years
if j==4; ind=logical(mom_yrs_educ2<12); end 
if j==5; ind=logical(mom_yrs_educ2==12); end
if j==6; ind=logical(mom_yrs_educ2>12); end    
pmaxq1=pmax82q1_rec(ind); mark_mathq1=mark_math82q1(ind); mark_mathq4lag=mark_math82q4lag(ind); median_math0=median_math_allpqrs_fall(ind); if j==6; ind=logical(isnan(mark_mathq4lag)==0); median_math0(ind)=mark_mathq4lag(ind); end

[p_pmaxq1_kudo2(:,:,j)] = Multiplecondition_mode_test(pmaxq1, mark_mathq1); %   % Parents % Mode and Median  %
[p_joint_pmaxq1_kudo(:,:,j)] = Multiplecondition_quantile_test(pmaxq1, mark_mathq1, 0.50);
% Parents (Mode, Median and Interval of Non-rejected quantiles) - conditional on mark of last quarter
[p_pmaxq1_lastqr2(:,:,j)] = Multiplecondition_mode_test_condX(pmaxq1, mark_mathq1, median_math0); %mark_mathq4lag median_math0
[p_joint_pmaxq1_lqr2(:,:,j)] = Multiplecondition_quantile_test_condX(pmaxq1, mark_mathq1, median_math0, 0.50); %[alpha_interval_pmaxq1_lqr2(:,:,j)] = Interval_nonrejected_quantiles_condX(pmaxq1, mark_mathq1, median_math_allpqrs_fall0, clevel); % median_math_allpqrs_fall mark_math82q4lag
end

for j=7:8; % Tests conditional on being or not a respondent who update guesses after being wrong in the past
if j==7; logical(noup_allw_pmax==0); end
if j==8; logical(noup_allw_pmax==1); end
pmaxq1=pmax82q1_rec(ind); mark_mathq1=mark_math82q1(ind); mark_mathq4lag=mark_math82q4lag(ind); median_math0=median_math_allpqrs_fall(ind); ind=logical(isnan(mark_mathq4lag)==0); median_math0(ind)=mark_mathq4lag(ind); 

[p_pmaxq1_kudo2(:,:,j)] = Multiplecondition_mode_test(pmaxq1, mark_mathq1); %   % Parents % Mode and Median  %
[p_joint_pmaxq1_kudo(:,:,j)] = Multiplecondition_quantile_test(pmaxq1, mark_mathq1, 0.50);
% Parents (Mode, Median and Interval of Non-rejected quantiles) - conditional on mark of last quarter
[p_pmaxq1_lastqr2(:,:,j)] = Multiplecondition_mode_test_condX(pmaxq1, mark_mathq1, median_math0); %mark_mathq4lag median_math0
[p_joint_pmaxq1_lqr2(:,:,j)] = Multiplecondition_quantile_test_condX(pmaxq1, mark_mathq1, median_math0, 0.50); %[alpha_interval_pmaxq1_lqr2(:,:,j2)] = Interval_nonrejected_quantiles_condX(pmaxq1, mark_mathq1, median_math_allpqrs_fall0, clevel); % median_math_allpqrs_fall mark_math82q4lag
end

for j=9:10; % Tests conditional on parents remembering less than 50% of the past marks or not
if j==9; ind=repmat(logical(math_pmemMean==0), [nr_y 1]); end
if j==10; ind=repmat(logical(math_pmemMean==1), [nr_y 1]); end
pmaxq1=pmax82q1_rec(ind); mark_mathq1=mark_math82q1(ind); mark_mathq4lag=mark_math82q4lag(ind); median_math0=median_math_allpqrs_fall(ind); if j==9; ind=logical(isnan(mark_mathq4lag)==0); median_math0(ind)=mark_mathq4lag(ind); end

[p_pmaxq1_kudo2(:,:,j)] = Multiplecondition_mode_test(pmaxq1, mark_mathq1); %   % Parents % Mode and Median  %
[p_joint_pmaxq1_kudo(:,:,j)] = Multiplecondition_quantile_test(pmaxq1, mark_mathq1, 0.50);
% Parents (Mode, Median and Interval of Non-rejected quantiles) - conditional on mark of last quarter
[p_pmaxq1_lastqr2(:,:,j)] = Multiplecondition_mode_test_condX(pmaxq1, mark_mathq1, median_math0); %mark_mathq4lag median_math0
[p_joint_pmaxq1_lqr2(:,:,j)] = Multiplecondition_quantile_test_condX(pmaxq1, mark_mathq1, median_math0, 0.50); %[alpha_interval_pmaxq1_lqr2(:,:,j2)] = Interval_nonrejected_quantiles_condX(pmaxq1, mark_mathq1, median_math_allpqrs_fall0, clevel); % median_math_allpqrs_fall mark_math82q4lag
end

% 3 - Saving results
warning on all; 
save('Mode_Median_BSStests_Mem', 'p_*'); %,  'alpha_*'
clear all; load('Mode_Median_BSStests_Mem');
toc; % End of program
