% This file performs Monte Carlo tests suggested by Das, Dominitz and Soest (1999) and Madeira (2015) for expectations of categorical variables
% We test therefore 1) the joint hypothesis that agents are rational and express their subjective Mode
% 2) the joint hypothesis that agents are rational and express their subjective Median

% It shows the results of Scenarios 1,2,3,4 in Tables 1.1, 1.2, 1.3

clear all; close all; tic;

% 0 - Format of the output
clevel=0.05; % confidence level of test for not-rejecting rationality
values=[1,2,3,4]'; nr_v=length(values); % Categorical outcomes and their nr
MC_nr=10000; % Nr of Monte Carlo replicas
%Prob_condExp = [[0.50, 0.35, 0.10, 0.05]', [0.25, 0.25, 0.25, 0.25]', [0.05, 0.20, 0.40, 0.35]', [0.05, 0.15, 0.40, 0.40]']; %V1 %Column k: Prob of Outcomes 1,2,3,4 conditional on Expectation being k=1,....
Prob_condExp = [[0.50, 0.45, 0.025, 0.025]', [0.25, 0.35, 0.35, 0.05]', [0.05, 0.15, 0.40, 0.40]', [0.025, 0.025, 0.475, 0.475]']; %V2

Cdf_condExp = cumsum(Prob_condExp); % Cdf of Outcomes
Cdf1_condExp=zeros(nr_v); Cdf1_condExp(2:end,:)=Cdf_condExp(1:end-1,:); % Cdf of Outcome k-1
Mode_assumption=[1,1,0,1]'; Median_assumption=[1,1,1,0]';

Prob_Exp=[0.25, 0.25, 0.25, 0.25]'; % Each group of Forecasters has the same probability in the population
Sample_eachExp=[25, 50, 75, 100, 150, 250, 500, 1000, 2500, 10000]';  % Size of groups for performing test statistic

Type1_Mode_MultiC=zeros(1, length(Sample_eachExp)); Type1_Median_MultiC=Type1_Mode_MultiC; Type1_Mode_MultiC2=Type1_Mode_MultiC; Type1_Median_MultiC2=Type1_Mode_MultiC;   
Type1_Mode_DDS=zeros(1, length(Sample_eachExp)); Type1_Median_DDS=Type1_Mode_DDS; 
%Type2_Mode_MultiC=Type1_Mode_MultiC; Type2_Median_MultiC=Type1_Mode_MultiC;
%Type2_Mode_DDS=Type1_Mode_DDS;nType2_Median_DDS=Type1_Mode_DDS;

for MCsize=1:length(Sample_eachExp); N=Sample_eachExp(MCsize);
    ind=ones(N,1); Exp=[1*ind;2*ind;3*ind;4*ind];
    Test_Mode_MultiC=NaN.*zeros(1,MC_nr); Test_Median_MultiC=Test_Mode_MultiC; Test_Mode_MultiC2=Test_Mode_MultiC; Test_Median_MultiC2=Test_Mode_MultiC;
    Test_Mode_DDS=NaN.*zeros(1,MC_nr); Test_Median_DDS=Test_Mode_DDS; 
    
    for MC_rep=1:MC_nr; Y=zeros(N,nr_v);
        for out1=1:nr_v; Uy=rand(N,1); % Create Outcomes conditional on Expectations
        for out2=1:nr_v; ind=logical(Uy>Cdf1_condExp(out2,out1) & Uy<=Cdf_condExp(out2,out1));  Y(ind,out1)=out2;        
        end
        end
        Y=reshape(Y,numel(Y),1); % Remember HR=1 is accepting rationality
        [p,p2]=Multiplecondition_mode_test_ALL2(Exp,Y); HR=logical(p>=clevel); Test_Mode_MultiC(:,MC_rep)=HR; % Madeira (2015) Mode test
        HR=logical(p2>=clevel); Test_Mode_MultiC2(:,MC_rep)=HR;
        [p,p2]=Multiplecondition_quantile_test_ALL2(Exp,Y,0.50); HR=logical(p>=clevel); Test_Median_MultiC(:,MC_rep)=HR; % Madeira (2015) Median test
        HR=logical(p2>=clevel); Test_Median_MultiC2(:,MC_rep)=HR;
        p=DDS_mode_test_ALL(Exp,Y); HR=logical(p>=clevel); Test_Mode_DDS(:,MC_rep)=HR; % DDS (1999) Mode test        
        p=DDS_quantile_test_ALL(Exp,Y,0.50); HR=logical(p>=clevel); Test_Median_DDS(:,MC_rep)=HR; % DDS (1999) Median test
    end
    
% Summarize Type I error (only applies if Rationality is true) % Remember HR=1 is accepting rationality %for out1=1:nr_v; Here out1==1 always
ind=logical(Test_Mode_MultiC~=1); Type1_Mode_MultiC(1,MCsize)=sum(ind); ind=logical(Test_Mode_DDS~=1); Type1_Mode_DDS(1,MCsize)=sum(ind); 
ind=logical(Test_Median_MultiC~=1); Type1_Median_MultiC(1,MCsize)=sum(ind); ind=logical(Test_Median_DDS~=1); Type1_Median_DDS(1,MCsize)=sum(ind);
ind=logical(Test_Mode_MultiC2~=1); Type1_Mode_MultiC2(1,MCsize)=sum(ind); ind=logical(Test_Median_MultiC2~=1); Type1_Median_MultiC2(1,MCsize)=sum(ind);

%Type II error only applies if Rationality is false
%ind=logical(Test_Mode_MultiC(out1,:)~=0); Type2_Mode_MultiC(out1,MCsize)=sum(ind); ind=logical(Test_Mode_DDS(out1,:)~=0); Type2_Mode_DDS(out1,MCsize)=sum(ind);
%ind=logical(Test_Median_MultiC(out1,:)~=0); Type2_Median_MultiC(out1,MCsize)=sum(ind); ind=logical(Test_Median_DDS(out1,:)~=0); Type2_Median_DDS(out1,MCsize)=sum(ind);
                  
end
[prob_v_cond] = Prob_outcomes_condY1(Exp, reshape(Y,numel(Y),1)); % Probability of Outcomes given Expectations

Type1_Mode_MultiC=Type1_Mode_MultiC/MC_nr;  Type1_Median_MultiC=Type1_Median_MultiC/MC_nr; 
Type1_Mode_DDS=Type1_Mode_DDS/MC_nr; Type1_Median_DDS=Type1_Median_DDS/MC_nr;
Type1_Mode_MultiC2=Type1_Mode_MultiC2/MC_nr;  Type1_Median_MultiC2=Type1_Median_MultiC2/MC_nr; 
%Type2_Mode_MultiC=Type2_Mode_MultiC/MC_nr; Type2_Median_MultiC=Type2_Median_MultiC/MC_nr;
%Type2_Mode_DDS=Type2_Mode_DDS/MC_nr; Type2_Median_DDS=Type2_Median_DDS/MC_nr;

% 3 - Saving results
save('MonteCarlo_DDS_tests_ALL2'); toc; % End of program  save('MonteCarlo_DDS_tests_ALL');
clear all; load('MonteCarlo_DDS_tests_ALL2'); %clear all; load('MonteCarlo_DDS_tests_ALL');
